@@ -45,8 +45,8 @@ def install_requirements():
     os.system(f"{source}{activate_file} && pip install -r requirements.txt")
 
 @app.command()
-def main(template_name):
-    cookiecutter(get_template_path(template_name))
+def main():
+    cookiecutter("https://github.com/MohammedBajuaifer/drf-starter-templates.git")
 
     install_requirements()
 
